@@ -1,28 +1,35 @@
 """
-Single access for different enstools-compressor utilities
+Command Line Interface for different enstools-compression utilities
 """
 
 # Few help messages
 compressor_help_text = """
+compress: 
+
+Tool to apply HDF5 compression filters to netCDF files. Compression specifications must follow the Compression Specification Format, more details below.
+
 Examples
 --------
 
 -Single file:
-    >>> enstools-compressions "input.nc" -o "output/folder/" 
+    >>> enstools-compression compress "input.nc" -o "output/folder/" 
     or
-    >>> enstools-compressions "input.nc" -o "output_file.nc"
+    >>> enstools-compression compress "input.nc" -o "output_file.nc"
 
 -Multiple files:
-    >>> enstools-compressions "input_1.nc" "input_2.nc" -o "output/folder/"
+    >>> enstools-compression compress "input_1.nc" "input_2.nc" -o "output/folder/"
 
--Path pattern:
-    >>> enstools-compressions "input_files_*" -o "output/folder/"  
+-Multiple files using wildcards:
+    >>> enstools-compression compress "input_files_*" -o "output/folder/"  
 
 
 To use custom compression parameters:
-    >>> enstools-compressions "input_files_*" -o "output/folder/" --compression compression_specification
+    >>> enstools-compression compress "input_files_*" -o "output/folder/" --compression compression_specification
 
-Where compression_specification can be a string that follows the Compression Specification Format (see more details in enstools-encoding.readthedocs.com) or a filepath
+Compression Specification Format
+--------------------------------
+
+The compression_specification can be a string that follows the Compression Specification Format (see more details in enstools-encoding.readthedocs.com) or a filepath
 to a configuration file in which we might have per variable specification.
 
 For lossless compression, we can choose the backend and the compression leven as follows
@@ -64,29 +71,30 @@ It is also possible to define a default option. For example:
 
 So, few examples with custom compression would be:
 
-    >>> enstools-compressions "input_files_*" -o "output/folder/" --compression lossless
+    >>> enstools-compression compress "input_files_*" -o "output/folder/" --compression lossless
 
-    >>> enstools-compressions "input_files_*" -o "output/folder/" --compression lossless,blosclz,9
+    >>> enstools-compression compress "input_files_*" -o "output/folder/" --compression lossless,blosclz,9
 
-    >>> enstools-compressions "input_files_*" -o "output/folder/" --compression lossy,zfp,rate,3.2
+    >>> enstools-compression compress "input_files_*" -o "output/folder/" --compression lossy,zfp,rate,3.2
     
-    >>> enstools-compressions "input_files_*" -o "output/folder/" --compression lossy,sz,abs,0.01
+    >>> enstools-compression compress "input_files_*" -o "output/folder/" --compression lossy,sz,abs,0.01
 
-    >>> enstools-compressions "input_files_*" -o "output/folder/" --compression compression_parameters.yaml
+    >>> enstools-compression compress "input_files_*" -o "output/folder/" --compression compression_parameters.yaml
 
 Also, it is possible to automatically find which are the compression parameters that must be applied
 to each variable in order to maintain a 0.99999 Pearson correlation and a 0.99 structural similarity.
 Be aware that that will cause an overhead due to the necessary time to find the appropriate parameters. 
 
-    >>> enstools-compressions "input_files_*" -o "output/folder/" --compression auto
+    >>> enstools-compression compress "input_files_*" -o "output/folder/" --compression auto
 
 It is possible to parallelize the compression of multiple files by launch a SLURM job for workers.
 To do that, specify the number of nodes to use:
 
-    >>> enstools-compressions -o "output/folder/" "input_files_*" --nodes 4
+    >>> enstools-compression compress -o "output/folder/" "input_files_*" --nodes 4
 
 """
 
+
 # For each possible usage (compress, analyze, ...) we will define a function to add
 # the corresponding command line arguments to the parser and another one to manage the call
 
@@ -159,10 +167,49 @@ def call_compressor(args):
 ###############################
 # Analyzer
 
+analyzer_help_text = """
+analyze: 
+
+Tool to find which compression specifications maximise the compression ratio while maintaining certain quality metrics provided by the argument **constrains**.
+
+Examples
+--------
+
+Analyze file using default constrains:
+
+>>> enstools-compression analyze "input_file.nc"
+
+
+Analyze file using custom constrains:
+
+>>> enstools-compression analyze "input_file.nc" --constrains "correlation_I:7,ssim_I:4"
+
+Analyze file and save the results to a file:
+
+>>> enstools-compression analyze "input_file.nc" -o "compression_specifications.yaml"
+
+Analyze files using a custom metric:
+
+>>> enstools-compression analyze "input_file.nc" --constrains "my_metric:5" --plugin my_metric.py
+
+where **my_metric.py** contains a function with the same name which expects two xarray as arguments (reference and target) 
+and returns an xarray with the time-series of the desired metric.
+
+
+Constrains
+----------
+
+The constrain specification must be provided in the following format:
+    >>> "metric1:value1,metric2:value2,metric3:value3"
+
+
+"""
+
+
 def add_subparser_analyzer(subparsers):
     import argparse
 
-    subparser = subparsers.add_parser('analyze', help='Analyze help',
+    subparser = subparsers.add_parser('analyze', help=analyzer_help_text,
                                       formatter_class=argparse.RawDescriptionHelpFormatter)
 
     subparser.add_argument("--constrains", dest="constrains",
@@ -245,10 +292,21 @@ def call_analyzer(args):
 ###############################
 # Find significand bits
 
+significant_bits_help_text = """
+significand:
+
+Tool to find the ammount of significand bits in a data file following the approach described in Klöwer et al 2021 _[1].
+
+.. [1] Klöwer, M., Razinger, M., Dominguez, J.J. et al. Compressing atmospheric data into its real information content.
+Nat Comput Sci 1, 713-724 (2021). https://doi.org/10.1038/s43588-021-00156-2
+
+"""
+
+
 def add_subparser_significand(subparsers):
     import argparse
 
-    subparser = subparsers.add_parser('significand', help='Analyze significand bits',
+    subparser = subparsers.add_parser('significand', help=significant_bits_help_text,
                                       formatter_class=argparse.RawDescriptionHelpFormatter)
     subparser.add_argument("--output", "-o", dest="output", default=None, type=str,
                            help="Path to the file where the configuration will be saved."
@@ -270,10 +328,17 @@ def call_significand(args):
 
 ###############################
 # Evaluator
+evaluate_help_text = """
+evaluate:
+
+Tool to quickly compare two datasets, mainly though to compare a compressed dataset with its reference.
+
+"""
+
 
 def add_subsubparser(subparsers):
     import argparse
-    subparser = subparsers.add_parser('evaluate', help='Evaluate help',
+    subparser = subparsers.add_parser('evaluate', help=evaluate_help_text,
                                       formatter_class=argparse.RawDescriptionHelpFormatter)
     subparser.add_argument("--reference", "-r", dest="reference_file", default=None, type=str,
                            help="Path to reference file. Default=%(default)s", required=True)
@@ -281,6 +346,8 @@ def add_subsubparser(subparsers):
                            help="Path to target file", required=True)
     subparser.add_argument("--plot", dest="plot", default=False, action='store_true',
                            help="Produce evaluation plots. Default=%(default)s")
+    subparser.add_argument("-g", "--gradients", dest="gradients", default=False, action='store_true',
+                           help="Compute gradients. Default=%(default)s")
     subparser.set_defaults(which='evaluator')
 
 
@@ -288,17 +355,25 @@ def call_evaluator(args):
     reference_file_path = args.reference_file
     target_file_path = args.target_file
     plot = args.plot
+    gradients = args.gradients
 
     from enstools.compression.api import evaluate
-    evaluate(reference_file_path, target_file_path, plot=plot)
+    evaluate(reference_file_path, target_file_path, plot=plot, create_gradients=gradients)
 
 
 ###############################
 # Pruner
+pruner_help_text = """
+pruner:
+
+Tool to prune a file up to a certain number of significant bits.
+
+"""
+
 
 def add_subparser_pruner(subparsers):
     import argparse
-    subparser = subparsers.add_parser('prune', help='Evaluate help',
+    subparser = subparsers.add_parser('prune', help=pruner_help_text,
                                       formatter_class=argparse.RawDescriptionHelpFormatter)
     subparser.add_argument("files", type=str, nargs="+",
                            help='List of files to compress. Multiple files and regex patterns are allowed.')
