@@ -1,3 +1,6 @@
 from .ZFPEmulator import ZFPEmulator
 from .FiltersEmulator import FilterEmulator
-from .LibpressioEmulator import LibpressioEmulator
\ No newline at end of file
+from .LibpressioEmulator import LibpressioEmulator
+
+# Define the default emulator
+default_emulator = FilterEmulator
